declare type $defs = Record<string, never>;

declare type AdditionalLogDetails = Record<string, unknown>;

/**
 * Assert a constraint. If the constraint is violated,
 * violationMessage is logged and an exception is thrown.
 *
 * @param constraintResult - Boolean or an expression which evaluates to a boolean.
 * @param violationMessage - The message to log when the constraint is violated.
 * @param logger - (Optional) The logger to use for logging the violation message.
 * @param context - (Optional) The context in which the constraint is being asserted.
 * @throws Error if the constraint is violated.
 *
 * @hidden
 */
export declare function assertConstraint(constraintResult: boolean, violationMessage: string, logger?: Logger, context?: string): void;

/**
 * Entry point for applications to configure and use the SDK.
 * This class contains various utility methods to initialize and shutdown the SDK.
 * Few other functionalities like setting log level, resetting idle timeout,
 * setting event listeners for SDK events are also provided in this class.
 */
export declare class AxpClientSdk {
    #private;
    /**
     * @hidden
     */
    constructor();
    static version(): string;
    /**
     * Sets the log level of SDK.
     *
     * @param logLevel - {@link LogLevel} to use.
     */
    static setLogLevel(logLevel: LogLevel): void;
    /**
     * Initialize the SDK and conversation with the given parameters.
     * Before any operation can be performed with the SDK, it must be initialized.
     * The initialization process creates a new session for the current user (identified by the JWT)
     * and returns a {@link AxpUserSession} object that contains the Conversation object corresponding
     * to the User's ongoing conversation.
     *
     * @param initParams - Initialization data required to initialize the SDK.
     * @returns A promise that resolves to {@link AxpUserSession} with conversation of type {@link AxpConversationCore}.
     */
    static init(initParams: AxpClientSdkInitParams): Promise<AxpUserSession<AxpConversationCore>>;
    /**
     * Initialize the SDK and conversation with the given parameters.
     * Before any operation can be performed with the SDK, it must be initialized.
     * The initialization process creates a new session for the current user (identified by the JWT)
     * and returns a {@link AxpUserSession} object that contains the Conversation object corresponding
     * to the User's ongoing conversation.
     *
     * @param initParams - Initialization data required to initialize the SDK.
     * @param EnhancedConversationClass - Enhanced(Mixed) class that extends {@link AxpConversationCore}, which was generated by applying the Mixins.
     * @returns A promise that resolves to {@link AxpUserSession} with conversation of type {@link EnhancedConversationClass}.
     *
     * @example
     *
     * const AxpConversationMixedClass = AxpMessagingConversation();
     *
     * const SDKUserSession = await AxpClientSdk.init({
     *   displayName: <displayName>,
     *   token: <jwt_token>,
     *   integrationId: <integration_id>,
     *   host: <region>,
     *   appKey: <appKey>,
     *   logLevel: <logLevel>,
     *   idleTimeoutDuration: <idleTimeOutDuration>,
     *   idleShutdownGraceTimeoutDuration: <graceTimeoutDuration>,
     *   jwtProvider: <jwtProviderImpl>
     * }, AxpConversationMixedClass);
     *
     */
    static init<T extends AxpConversationConstructable<AxpConversationCore>>(initParams: AxpClientSdkInitParams, EnhancedConversationClass: T): Promise<AxpUserSession<InstanceType<T>>>;
    /**
     * Get the default conversation for this SDK instance.
     * Before calling this method, it is mandatory for the SDK to be initialized.
     *
     * Note: In order to fully leverage the advantages of TypeScript, it is recommended to specify the type of the conversation class that was provided to the SDK during initialization. See {@link init} method. If no class was provided to the SDK during initialization, then the default conversation class will be {@link AxpConversationCore} and there is no need to specify the type.
     *
     * @example
     * const defaultConversation = AxpClientSdk.getDefaultConversation<typeof AxpConversationMixedClass>();
     *
     * @template T - The type of the conversation class that was provided to the SDK during initialization.
     * @returns InstanceType of class {@link T} that extends {@link AxpConversationCore} and was provided to the SDK in {@link init} method.
     *
     */
    static getDefaultConversation<T extends Constructable<AxpConversationCore>>(): InstanceType<T>;
    /**
     * Set a new Jwt for the SDK to invoke APIs at server.
     * Before calling this method, it is mandatory for the SDK to be initialized.
     *
     * @param token - New JWT token to be set.
     *
     */
    static setJwt(token: string): void;
    /**
     * Shutdown the SDK and closes the session with AXP.
     * After shutdown, if the SDK is required to be used again, re-initialize it by calling {@link init}.
     * Before calling this method, it is mandatory for the SDK to be initialized.
     *
     * @param shutdownReason Reason for shutting down the SDK.
     */
    static shutdown(shutdownReason?: ShutdownReason): Promise<void>;
    /**
     * Reset the idle timer to indicate the SDK that the user session is still active.
     * The SDK already resets the timeout when it receives a request internally from the modules or other sub modules(AXP Messaging).
     *
     * Invoke this method only when client want to indicate a user's activity visible only to the client (apart from the above mentioned activities).
     *
     */
    static resetIdleTimeout(): void;
    /**
     * Attach event handler callback that needs to be invoked when SDK gets initialized.
     *
     * @param eventHandler - The event handler callback.
     * @returns Unique event handler id that was generated by SDK when the event handler was attached.
     */
    static addSdkInitializedListener<T extends Constructable<AxpConversationCore>>(eventHandler: EventHandler<AxpUserSession<InstanceType<T>>>): string;
    /**
     * Remove the event handler callback that was attached to the SDK initialization event.
     * @param eventHandlerId Event handler id that was received at the time of attaching the event handler.
     */
    static removeSdkInitializedListener(eventHandlerId: string): void;
    /**
     * Attach event handler callback that needs to be invoked when SDK shuts down.
     *
     * @param eventHandler - The event handler callback.
     * @returns Unique event handler id that was generated by SDK when the event handler was attached.
     */
    static addSdkShutdownListener(eventHandler: EventHandler<SDKShutdown>): string;
    /**
     * Remove the event handler callback that was attached to the SDK shutdown event.
     * @param eventHandlerId - Event handler id that was received at the time of attaching the event handler.
     */
    static removeSdkShutdownListener(eventHandlerId: string): void;
    /**
     * Attach event handler callback that needs to be invoked when user has remained inactive for the idleTimeout duration.
     *
     * @param eventHandler - The event handler callback.
     * @returns Unique event handler id that was generated by SDK when the event handler was attached.
     */
    static addIdleTimeOutInvokedListener(eventHandler: EventHandler<IdleTimeout>): string;
    /**
     * Remove the event handler callback that was attached to the idleTimeout event.
     *
     * @param eventHandlerId - Event handler id that was received at the time of attaching the event handler.
     */
    static removeIdleTimeOutInvokedListener(eventHandlerId: string): void;
}

/**
 * Constants related to the AxpClientSdk.
 * @hidden
 */
export declare const AxpClientSdkConstants: {
    NEW_LOG_LEVEL: string;
    SESSION_NOT_FOUND: string;
    EVENT_DISPATCHING_DISABLED: string;
    WEB_CLIENT_TYPE: string;
    SDK_SHUTDOWN: string;
    SDK_NOT_INITIALIZED: string;
    PARTICIPANT_ADDED: string;
    PARTICIPANT_DISCONNECTED: string;
    PARTICIPANT_UPDATED: string;
    PARTICIPANT_REMOVED: string;
    ENGAGEMENT_CREATED: string;
    SESSION_ERROR: string;
    REGION_TRAILING_FQDN: string;
    HTTPS: string;
    JWT_STATUS_CHANGED: string;
};

/**
 * Parameters to initialize the SDK and create a session for this SDK instance on the server.
 */
export declare type AxpClientSdkInitParams = {
    /**
     * Hostname of the AXP API endpoint to connect to or an AXP region code.
     * If a region code is provided (e.g., "na" for North America),
     * it will be converted to the corresponding hostname (e.g., "na.api.avayacloud.com").
     * If a full hostname is provided (e.g., "na.api.avayacloud.com"), it will be used as is.
     */
    host: string;
    /**
     * The 36 character unique UUID for the tenant that is configured on AXP.
     */
    integrationId: string;
    /**
     * Application Key which is required to access the API for your Account.
     */
    appKey: string;
    /**
     * Initial Jwt to initialize the SDK
     */
    token: string;
    /**
     * Interface implemented by applications to access a valid JWT for the SDK using the connection to their own application server.
     */
    jwtProvider: JwtProvider;
    /**
     * How the user is presented to others.
     */
    displayName?: string;
    /**
     * The key value pairs capturing information about the user's session.
     */
    sessionParameters?: Record<string, string>;
    /**
     * Logging level to use for SDK.
     */
    logLevel?: LogLevel;
    /**
     * The duration (in milliseconds) till which user is allowed to remain inactive, after which grace timer will start.
     */
    idleTimeoutDuration?: number;
    /**
     * The duration (in milliseconds) till which user is allowed to remain inactive after the idle timeout. SDK will shutdown on timeout.
     */
    idleShutdownGraceTimeoutDuration?: number;
};

/**
 * @internal
 */
export declare type AxpConversationConstructable<T = {}> = new (conversationModuleContext: AxpConversationModuleContext) => T;

/**
 * Represents the core functionality of an Axp Conversation.
 */
export declare class AxpConversationCore implements AxpConversationCoreTrait {
    #private;
    /**
     * The unique identifier of the conversation.
     */
    conversationId: string;
    /**
     * @hidden
     * Creates an instance of AxpConversationCore.
     * @param conversationModuleContext - The context of the conversation module.
     */
    constructor(conversationModuleContext: AxpConversationModuleContext);
    /**
     * Attach event handler callback that needs to be invoked when a participant is added to the conversation.
     * @param handler - The event handler function.
     * @returns string Unique event handler id that was generated by SDK when the event handler was attached.
     *
     * @example
     * const participantAddedHandlerId = conversation.addParticipantAddedListener((eventPayload) => {
     *      console.log("Participant added: ", eventPayload);
     * });
     *
     */
    addParticipantAddedListener(handler: EventHandler<ParticipantAdded>): string;
    /**
     * Attach event handler callback that needs to be invoked when a participant is disconnected from the conversation.
     *
     * @param handler
     * @returns string Unique EventHandlerId that was generated by SDK when the event handler was attached.
     *
     * @example
     * const participantDisconnectedHandlerId = conversation.addParticipantDisconnectedListener((eventPayload) => {
     *      console.log("Participant disconnected: ", eventPayload);
     * });
     */
    addParticipantDisconnectedListener(handler: EventHandler<ParticipantDisconnected>): string;
    /**
     * Remove the event handler callback that was attached to the participant added event.
     *
     * @param eventHandlerId
     */
    removeParticipantAddedListener(eventHandlerId: string): void;
    /**
     * Remove the event handler callback that was attached to the participant disconnected event.
     *
     * @param eventHandlerId
     *
     */
    removeParticipantDisconnectedListener(eventHandlerId: string): void;
    /**
     * The key value pairs that are passed as context parameters
     * for the conversation to AXP. AXP uses this information to
     * make business decisions on how the engagement is treated.
     * For example, the client application might want to send hints
     * about customer's interest based on the customer's searches or
     * FAQ browsing.
     *
     * @param parameters - The context parameters to set.
     *
     * @example
     * conversation.setContextParameters(\{"availableBalance": "1000"\});
     *
     */
    setContextParameters(parameters: Record<string, string>): void;
    /**
     * Gets the participants of the conversation.
     */
    get participants(): Readonly<Array<Participant>>;
}

/**
 * Represents the traits of the AXP Core Conversation.
 */
export declare interface AxpConversationCoreTrait {
    /**
     * Attach event handler callback that needs to be invoked when a
     * participant is added to the conversation.
     *
     * @param handler - The event handler function to be called when a
     * participant is added.
     * @returns A unique identifier for the event handler.
     */
    addParticipantAddedListener(handler: EventHandler<ParticipantAdded>): string;
    /**
     * Attach event handler callback that needs to be invoked when a participant
     * is disconnected from the conversation.
     *
     * @param handler - The event handler function to be called when a participant
     * is disconnected.
     * @returns A unique identifier for the event handler.
     */
    addParticipantDisconnectedListener(handler: EventHandler<ParticipantDisconnected>): string;
    /**
     * Removes a event handler attached to the "participantAdded" event.
     *
     * @param eventHandlerId - The unique identifier of the event handler to be removed.
     */
    removeParticipantAddedListener(eventHandlerId: string): void;
    /**
     * Removes a event handler attached to the "participantDisconnected" event.
     *
     * @param eventHandlerId - The unique identifier of the event handler to be removed.
     */
    removeParticipantDisconnectedListener(eventHandlerId: string): void;
    /**
     * Gets the list of participants in the conversation.
     */
    readonly participants: Readonly<Array<Participant>>;
    /**
     * The key value pairs that are passed as context parameters
     * for the conversation to AXP. AXP uses this information to
     * make business decisions on how the engagement is treated.
     * For example, the client application might want to send hints
     * about customer's interest based on the customer's searches
     * or FAQ browsing.
     *
     * @param parameters - The context parameters to set.
     *
     * @example
     * conversation.setContextParameters({"availableBalance": "1000"});
     *
     */
    setContextParameters(parameters: Record<string, string>): void;
}

/**
 * @hidden
 */
export declare type AxpConversationModuleContext = {
    conversationId: string;
    conversationDetails: ConversationDetails.Conversation;
    restController: RestController;
    jwt: JWT;
    config: SDKInternalConfig;
    isSessionValid: () => boolean;
    loggerFactory: LoggerFactory;
    eventDispatcher: EventDispatcher;
    inactivityTimerController: InactivityTimerController;
    contextParameters: ContextParameters;
    sessionPollingManager: SessionPollingManager;
};

/**
 * Constants related to AxpRegion.
 * These regions were present at the time of writing this code.
 * It is not mandatory that user can send only provided regions.
 * In future if any new region is added, user can send that
 * region as well without using AxpRegionConstants.
 */
export declare const AxpRegionConstants: {
    NORTH_AMERICA: string;
    SOUTH_AMERICA: string;
    UNITED_KINGDOM: string;
    EUROPE: string;
    ASIA_PACIFIC: string;
    AUSTRALIA: string;
    CANADA: string;
};

declare enum AxpSessionInactivityTimers {
    Idle = "AxpSessionIdleTimer",
    Grace = "AxpSessionGraceTimer"
}

/**
 * User session object which contains the conversation details and user information.
 */
export declare type AxpUserSession<T> = {
    /**
     * Display name of the user.
     */
    displayName?: string;
    /**
     * Unique identifier for the participant(User).
     */
    participantId?: string;
    /**
     * Session parameters of the user.
     */
    sessionParameters?: Record<string, string>;
    /**
     * The user's currently active Conversations.
     */
    conversations: Array<T>;
};

/**
 * Enum representing channels supported by SDK.
 * @hidden
 */
export declare enum Channel {
    MESSAGING = "messaging"
}

declare interface components {
    schemas: {
        UploadUrl: {
            /** @description The unique 36 character internal id for the attachment */
            attachmentId: string;
            /** @description Presigned Url */
            presignedUrl: string;
        };
        Session: {
            /**
             * @description The display name of the customer. Note, this field will be ignored if a customer name was already provided at the time of generating the JWT token.
             * @example John Doe
             */
            displayName?: string;
            /**
             * @description The type of client making the request
             * @example web
             */
            clientType: string;
            /** @description Optional key/value session parameters for capturing properties of the user and the user's client device. Key is limited to 64 characters */
            sessionParameters?: {
                [key: string]: string;
            };
            /** @description The unique 36 character internal id that represents the session. */
            sessionId?: string;
            /** @description The id that represents the participant. */
            participantId?: string;
            notificationParams?: components["schemas"]["NotificationParams"];
            /**
             * Format: date-time
             * @description The datetime when the session was created (in ISO 8601 format including timezone, 'yyyy-MM-dd'T'HH:mm:ss[.SSS]Z')
             */
            createdAt?: string;
        };
        NotificationParams: {
            /** @description The unique 36 character internal id of the Push Notification Configuration (configured on admin portal), that will be used to send the push notifications for the session. */
            pushConfigId: string;
        };
        SessionResponse: components["schemas"]["Session"] & {
            /** @description The list of active engagements */
            engagements?: components["schemas"]["Engagement"][];
            /** @description The list of active conversations. In single-conversation mode, only the user's default conversation will be part of this array */
            conversations?: components["schemas"]["Conversation"][];
        };
        CreateEngagement: {
            /** @description The unique 36 character internal id that represents the session. */
            sessionId: string;
            /** @description Optional key/value context information on the dialog. This information might be used to make business decisions on how the dialog is treated. For example, the client application might want to send hints about customer's interest based on the customer's searches or FAQ browsing. Key is limited to 64 characters */
            engagementParameters?: {
                [key: string]: string;
            };
            /** @description Optional flag to indicate if this is a priority WebRTC engagement. Default value is false */
            isPriority?: boolean;
            /** @description Optional key/value media preferences. This information is used to setup WebRTC engagement. Key is limited to 64 characters */
            mediaPreferences?: {
                [key: string]: boolean;
            };
        };
        DisconnectEngagement: {
            /**
             * @description Reason for disconnecting from the chat dialog.
             * @example USER_CLOSED
             * @enum {string}
             */
            reason?: "USER_CLOSED" | "USER_INACTIVE" | "SYSTEM_CLOSED";
            /** @description The unique 36 character internal id that represents the dialog. */
            dialogId: string;
            /** @description The unique 36 character internal id that represents the session. */
            sessionId: string;
        };
        JoinEngagement: {
            /** @description The unique 36 character internal id that represents the dialog. */
            dialogId: string;
            /** @description The unique 36 character internal id that represents the session. */
            sessionId: string;
        };
        /** @description The conversation */
        Conversation: {
            /** @description The unique 36 character internal id that represents the conversation. */
            conversationId: string;
        };
        /** @description The media specific element inside the engagement */
        Engagement: {
            /** @description The unique 36 character internal id that represents the engagement. */
            engagementId: string;
            /** @description The unique 36 character internal id that represents the conversation. */
            conversationId?: string;
            /** @description Optional key/value context information on the dialog. This information might be used to make business decisions on how the dialog is treated. For example, the client application might want to send hints about customer's interest based on the customer's searches or FAQ browsing */
            engagementParameters?: {
                [key: string]: string;
            };
            /** @description The list of active dialogs */
            dialogs?: components["schemas"]["Dialog"][];
        };
        /** @description The media specific element inside the dialog. */
        Dialog: {
            /** @description The unique 36 character internal id that represents the dialog. */
            dialogId: string;
            dialogStatus: components["schemas"]["DialogStatus"];
            /** @description List of participants */
            participants: components["schemas"]["Participant"][];
            /**
             * Format: date-time
             * @description The datetime when the dialog was created (in ISO 8601 format including timezone, 'yyyy-MM-dd'T'HH:mm:ss[.SSS]Z')
             */
            createdAt: string;
            /**
             * Format: date-time
             * @description The datetime when the dialog was last updated (in ISO 8601 format including timezone, 'yyyy-MM-dd'T'HH:mm:ss[.SSS]Z')
             */
            lastUpdatedAt: string;
        };
        /**
         * @description Status of the dialog.
         * @enum {string}
         */
        DialogStatus: "PENDING" | "ACTIVE" | "TERMINATING" | "TERMINATED";
        Endpoint: {
            /** @description The unique 36 character internal id that represents the session. */
            sessionId: string;
            /**
             * @description The type of client making the request
             * @example web
             */
            clientType: string;
            /**
             * @description The display name of the customer. Note, this field will be ignored if a customer name was already provided at the time of generating the JWT token.
             * @example John Doe
             */
            displayName: string;
            /** @description Endpoint session expiration time in seconds */
            ttl?: number;
        };
        EndpointResponse: WithRequired<{
            /** @description The unique 36 character internal id that represents the endpoint. */
            endpointId?: string;
            /**
             * @description The display name of the customer. Note, this field will be ignored if a customer name was already provided at the time of generating the JWT token.
             * @example John Doe
             */
            displayName?: string;
            /** @description The unique 36 character internal id that represents the session. */
            sessionId?: string;
            /** @description The unique id that represents the websocket session */
            webSocketSessionId?: string;
            /** @description The unique token requires to establish websocket session */
            webSocketSessionToken?: string;
        }, "endpointId" | "sessionId" | "webSocketSessionId" | "webSocketSessionToken">;
        /** @description The association between a dialog and a participant */
        Participant: {
            /** @description The id that represents the participant. */
            participantId: string;
            participantType: components["schemas"]["ParticipantType"];
            /** @description The display name of the participant */
            displayName?: string;
        };
        Pagination: {
            /** @description The current page number. */
            pageNumber?: number;
            /** @description The max number of records that can be retrieved on this page. */
            pageSize?: number;
            /** @description The total number of records. */
            total?: number;
        };
        /** @description Links of the adjacent pages */
        Links: {
            /** @description URL of the previous page. Blank if currently on the first page. */
            prev?: string;
            /** @description URL of the next page. Blank if currently on the last page. */
            next?: string;
        };
        /** @description A message page that is sent in response of request to retrieving messages */
        MessagesPage: {
            pagination?: components["schemas"]["Pagination"];
            messages?: components["schemas"]["Message"][];
            links?: components["schemas"]["Links"];
        };
        /** @description A conversation message */
        Message: {
            /** @description The unique 36 character internal id for this specific message. */
            messageId: string;
            /** @description The unique 36 character internal id that represents the dialog. */
            dialogId?: string;
            /** @description The unique 36 character internal id that represents the engagement. */
            engagementId?: string;
            /** @description The unique 36 character internal id that represents the conversation. */
            conversationId?: string;
            /** @description The unique 36 character id (uuid) that represents the sender of the message */
            senderParticipantId: string;
            body: components["schemas"]["BodyElement"];
            /** @description The index of the message within the context of the dialog */
            messageIndex?: number;
            /** @description The unique 36 character internal id for the message that is the parent of this message */
            parentMessageId?: string;
            participantType: components["schemas"]["ParticipantType"];
            /** @description Display name of the participant */
            displayName?: string;
            /** @description List of Attachments */
            attachments?: readonly components["schemas"]["Attachment"][];
            /**
             * Format: date-time
             * @description The datetime when the message was received by the Contact Center (in ISO 8601 format including timezone, 'yyyy-MM-dd'T'HH:mm:ss[.SSS]Z')
             */
            receivedAt?: string;
            /**
             * Format: date-time
             * @description The datetime when the message was updated by the Contact Center (in ISO 8601 format including timezone, 'yyyy-MM-dd'T'HH:mm:ss[.SSS]Z')
             */
            lastUpdatedAt?: string;
        };
        SendMessage: {
            /** @description The unique 36 character internal id that represents the dialog. */
            dialogId: string;
            /** @description The unique 36 character internal id that represents the session. */
            sessionId: string;
            body: components["schemas"]["BodyElement"];
            /**
             * @description The unique 36 character internal id for the message that is the parent of this message.
             * @example c44545f6-c8a4-445a-abe8-983a5cbe1ed0
             */
            parentMessageId?: string;
        };
        GenerateUploadUrl: {
            /** @description Name of the attachment to be uploaded */
            attachmentName: string;
            /**
             * @description Type of the attachment to be uploaded
             * @example image/png
             */
            attachmentType: string;
            /**
             * Format: int64
             * @description The size of the attachment in bytes
             * @example 922
             */
            attachmentSize: number;
        };
        MessageSent: components["schemas"]["Message"] & {
            /** @description The unique 36 character internal id for this specific session. */
            sessionId?: string;
        };
        /** @description Definition of the body element such as the type of element, the message text and format */
        BodyElement: {
            /**
             * @description The type of the body element such as text, image, file, postback, carousel, location
             * @example text
             */
            elementType: string;
            elementText: components["schemas"]["ElementText"];
            richMediaPayload?: components["schemas"]["RichMediaPayload"];
        };
        /** @description Rich media payload data */
        RichMediaPayload: {
            /** @description An array of ids of the media attached to the message. Currently restricted to a single attachment per message */
            attachmentIds?: components["schemas"]["AttachmentId"][];
            selectedAction?: components["schemas"]["Action"];
            /** @description An array of actions associated with the message */
            actions?: readonly components["schemas"]["Action"][];
            /** @description An array of items associated with the message */
            items?: readonly components["schemas"]["Item"][];
            coordinates?: components["schemas"]["Coordinates"];
            location?: components["schemas"]["Location"];
        };
        /** @description Meta information about the media */
        Attachment: {
            /** @description The unique 36 character internal id for the attachment */
            attachmentId: string;
            /** @description The name of the attachment */
            name: string;
            /**
             * Format: int64
             * @description The size of the attachment in bytes
             */
            size: number;
            /** @description The content type of the attachment */
            contentType: string;
            /** @description The content id of the attachment */
            contentId?: string;
            /** @description The URL link to retrieve the attachment */
            url: string;
            /** @description The text describing the caption of the attachment */
            captionText?: string;
            /** @description The URL link to retrieve the thumbnail of the attachment */
            thumbnailUrl?: string;
            /** @description Any additional properties of the attachment like labels, tags, revision numbers, display properties, etc. */
            additionalProperties?: {
                [key: string]: string;
            };
        };
        /** @description An action button that the user can click to trigger an action */
        Action: {
            /**
             * @description The type of action. Supported types of action types are link, reply, postback, and locationRequest. Messages sent by customer are allowed to have only reply and postback as action type.
             * @example postback
             */
            type: string;
            /**
             * @description The text on an action button
             * @example Book Appointment
             */
            text?: string;
            /**
             * @description The payload of 'postback' or 'reply' action button
             * @example BOOK_APPOINTMENT
             */
            payload?: string;
            /**
             * Format: uri
             * @description The URI that will be used by the clients when 'link' action button is clicked. Supports only https url.
             * @example https://example.com/items/info
             */
            uri?: string;
            /**
             * Format: uri
             * @description The URL of the image of the icon on a 'reply' action button.  Supports only https url.
             * @example https://example.com/images/icon.png
             */
            iconUrl?: string;
        };
        /** @description The coordinates of a location */
        Coordinates: {
            /**
             * Format: double
             * @description The latitude of a location
             * @example -18.516634
             */
            lat: number;
            /**
             * Format: double
             * @description The longitude of a location
             * @example 73.928104
             */
            long: number;
        };
        /** @description The information about a location */
        Location: {
            /**
             * @description The address of the location
             * @example Nth Floor, UVW Park, XYZ Street, Some Country, PIN CODE - 123456
             */
            address?: string;
            /**
             * @description The name of the location
             * @example ABC Enterprises
             */
            name?: string;
        };
        /** @description An item of a carousel or a list */
        Item: {
            /**
             * @description The title of the item in carousel or list
             * @example Tacos
             */
            title: string;
            /**
             * Format: uri
             * @description The URL of the image to be shown inside the item in carousel or list
             * @example https://example.com/images/image.png
             */
            mediaUrl?: string;
            /**
             * @description Description of the item in carousel or list
             * @example Car with hybrid features
             */
            description?: string;
            /** @description An array of actions associated with the item in carousel or list */
            actions: components["schemas"]["Action"][];
        };
        /** @description Id of attachment uploaded along with the message */
        AttachmentId: string;
        /** @description The text of the message body */
        ElementText: {
            /**
             * @description Text of the body
             * @example Need documentation for insurance details
             */
            text: string;
            textFormat?: components["schemas"]["TextFormat"];
        };
        /**
         * @description The text format of the message in the body
         * @example PLAINTEXT
         * @enum {string}
         */
        TextFormat: "PLAINTEXT" | "HTML" | "MARKDOWN";
        /**
         * @description The type of participant
         * @enum {string}
         */
        ParticipantType: "CUSTOMER" | "AGENT" | "SUPERVISOR" | "SYSTEM" | "BOT";
        /** @description Common event data */
        Event: {
            /** @description The unique id of the event */
            eventId: string;
            /**
             * @description The type of digital event to subscribe for
             * @enum {string}
             */
            eventType: "MESSAGE" | "PARTICIPANT_ADDED" | "PARTICIPANT_DISCONNECTED" | "ENGAGEMENT_CREATED" | "ENGAGEMENT_ERROR";
            /**
             * Format: date-time
             * @description The datetime of when the event was generated by the Contact Center (in ISO 8601 format including timezone, 'yyyy-MM-dd'T'HH:mm:ss[.SSS]Z')
             */
            eventDate: string;
            /**
             * @description The unique 36 character internal id that represents the session.
             * @example d3c8400d-d34f-4451-8316-4333334fac34
             */
            sessionId: string;
            /** @description The unique 36 character internal id that represents the dialog. */
            dialogId?: string;
            /** @description The unique 36 character internal id that represents the engagement. */
            engagementId?: string;
            /** @description The unique 36 character internal id that represents the conversation. */
            conversationId?: string;
            participant?: components["schemas"]["Participant"];
            message?: components["schemas"]["MessageEvent"];
            error?: components["schemas"]["ErrorEvent"];
        };
        /** @description Message Event */
        MessageEvent: {
            /** @description The unique 36 character internal id for this specific message. */
            messageId: string;
            body: components["schemas"]["BodyElement"];
            attachments?: readonly components["schemas"]["Attachment"][];
            /** @description The index of the message within the context of the dialog */
            messageIndex?: number;
            /** @description The unique 36 character internal id for the message that is the parent of this message */
            parentMessageId?: string;
            /**
             * Format: date-time
             * @description The datetime when the message was received by the Contact Center (in ISO 8601 format including timezone, 'yyyy-MM-dd'T'HH:mm:ss[.SSS]Z')
             */
            receivedAt?: string;
            /**
             * Format: date-time
             * @description The datetime when the message was updated by the Contact Center (in ISO 8601 format including timezone, 'yyyy-MM-dd'T'HH:mm:ss[.SSS]Z')
             */
            lastUpdatedAt?: string;
        };
        /** @description Error Event */
        ErrorEvent: {
            /** @description The type of error */
            type: string;
            /** @description The title (summary) of the error */
            title: string;
            /** @description The detailed description of the error */
            detail?: string;
        };
        /** @description <b>Problem Detail</b> as a way to carry machine-readable details of errors in a HTTP response to avoid the need to define new error response formats for HTTP APIs <a href="https://tools.ietf.org/html/rfc7807">RFC 7807</a> */
        Problem: {
            /**
             * Format: uri
             * @description An absolute URI that identifies the problem type. When dereferenced, it SHOULD provide human-readable documentation for the problem type (e.g., using HTML).
             *
             * @default about:blank
             * @example https://developers.avayacloud.com/onecloud-ccaas/docs/error-handling#constraint-violation
             */
            type?: string;
            /**
             * @description A short, summary of the problem type. Written in english and readable for engineers (usually not suited for non technical stakeholders and not localized).
             *
             * @example Service Unavailable
             */
            title?: string | null;
            /**
             * Format: int32
             * @description The HTTP status code generated by the origin server for this occurrence of the problem.
             *
             * @example 503
             */
            status?: number | null;
            /**
             * @description A human readable explanation specific to this occurrence of the problem.
             *
             * @example Connection to database timed out
             */
            detail?: string | null;
            /**
             * Format: uri
             * @description An absolute URI that identifies the specific occurrence of the problem. It may or may not yield further information if dereferenced.
             */
            instance?: string | null;
            /**
             * @description A list of violations that occurred as a result of invalid data provided as part of a request.
             *
             * @example [
             *   {
             *     "field": "emailAddress",
             *     "message": "must not be null",
             *     "code": 20002
             *   },
             *   {
             *     "field": "accountId",
             *     "message": "must match \"^[a-zA-Z]{6}$\"",
             *     "code": 20006
             *   }
             * ]
             */
            violations?: {
                /**
                 * @description The name of the field in the request that caused the violation. This can be the name of a path parameter, query parameter, or a field within the request body.
                 *
                 * @example accountId
                 */
                field?: string;
                /**
                 * @description A human readable explanation specific to this occurrence of the violation.
                 *
                 * @example must match "^[a-zA-Z]{6}$"
                 */
                message?: string;
                /**
                 * Format: int32
                 * @description The violation code generated by the server for this occurrence of the violation. Use this code when implementing any error handling logic instead of the message, as the message can change.
                 *
                 * @example 20006
                 */
                code?: number;
            }[] | null;
        };
    };
    responses: {
        /** @description Bad Request */
        BadRequestCreateSession: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
        /** @description Bad Request */
        BadRequestCreateEngagement: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
        /** @description Bad Request */
        BadRequestGenerateUploadURL: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
        /** @description Bad Request */
        BadRequest: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
        /** @description Unauthorized. */
        Unauthorized: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
        /** @description Forbidden. */
        Forbidden: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
        /** @description Not Found. */
        NotFound: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
        /** @description Internal Server Error */
        InternalServerError: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
        /** @description Service Unavailable */
        ServiceUnavailable: {
            content: {
                "application/problem+json": components["schemas"]["Problem"];
            };
        };
    };
    parameters: {
        /** @description The unique 36 character internal id that represents the session. */
        sessionId: string;
        /** @description The unique 36 character id for this specific chat integration */
        integrationId: string;
        /** @description The type of integration. 'integrations' for Chat SDK and 'messaging-integrations' for Messaging SDK */
        integrationType: string;
        /** @description The unique 36 character internal id that represents the conversation. */
        conversationId: string;
        /** @description The unique 36 character internal id that represents the engagement. */
        engagementId: string;
        /** @description The unique 36 character internal id that represents the dialog. */
        dialogId: string;
        /** @description The unique 36 character internal id that represents the endpoint. */
        endpointId: string;
        /** @description The max number of messages in a page. Default value is 10, max value is 50 */
        pageSize?: number;
        /** @description Page number of messages. Default value is 1 */
        pageNumber?: number;
    };
    requestBodies: never;
    headers: never;
    pathItems: never;
}

/**
 * @hidden
 */
export declare type Constructable<T = {}> = new (...args: any[]) => T;

/**
 * Represents the context parameters for the conversation.
 * Using these parameters backend server will be able to route
 * the request to appropriate queue.
 * @hidden
 */
export declare class ContextParameters {
    private _parameters;
    constructor(parameters?: Record<string, string>);
    get parameters(): Record<string, string>;
    reset(parameters: Record<string, string>): void;
    get(key: string): string | undefined;
    set(key: string, value: string): void;
    delete(key: string): void;
    clear(): void;
}

/**
 * These types mirror the server-side types from OpenAPI spec.
 * They are defined here to avoid exposing the server-side types to the
 * client-side code as the openapi-generated package
 * (\@avaya-internal/axp-openapi-generated) will not be published to npm
 * and will not be available to the consumer of the core and other packages.
 * These are re-exported from the core package to be used by
 * other packages like messaging and web rtc.
 * @hidden
 */
export declare namespace ConversationDetails {
    export type Conversation = {
        sessionId: string;
        conversationId: string;
        participantId: string;
        engagements: Array<Engagement>;
    };
    export type Engagement = {
        engagementId: string;
        engagementParameters: Record<string, string>;
        dialogs: Array<Dialog>;
    };
    export type Dialog = {
        dialogId: string;
        dialogStatus: DialogStatus;
        createdAt: string;
        lastUpdatedAt: string;
        participants: Array<{
            participantId: string;
            participantType: ParticipantType;
            displayName?: string;
        }>;
    };
    export enum DialogStatus {
        PENDING = "PENDING",
        ACTIVE = "ACTIVE",
        TERMINATING = "TERMINATING",
        TERMINATED = "TERMINATED"
    }
    export enum ParticipantType {
        CUSTOMER = "CUSTOMER",
        AGENT = "AGENT",
        SUPERVISOR = "SUPERVISOR",
        BOT = "BOT",
        SYSTEM = "SYSTEM"
    }
}

/**
 * @hidden
 * Fired to share the latest conversation details with the Modules.
 * Represents the latest view of the conversation details.
 */
export declare interface ConversationSync extends SDKEvent {
    conversations: ConversationDetails.Conversation[];
}

/**
 * Type of events for whom client as well as module(core/messaging) event handlers will be invoked from core module.
 * @hidden
 */
export declare enum CoreEventType {
    /**
     * Fired when SDK is initialized successfully
     */
    INITIALIZED = "INITIALIZED",
    /**
     * Fired when SDK has been shutdown successfully
     */
    SHUTDOWN = "SHUTDOWN",
    /**
     * Fired when a new Participant is added to conversation
     */
    PARTICIPANT_ADDED = "PARTICIPANT_ADDED",
    /**
     * Fired when a Participant is removed from conversation
     */
    PARTICIPANT_DISCONNECTED = "PARTICIPANT_DISCONNECTED",
    /**
     * Fired when the SDK is about to be shutdown due to inactivity.
     * Once the event is fired, the SDK will wait for the grace period before shutting down.
     */
    IDLE_TIMEOUT = "IDLE_TIMEOUT",
    /**
     * Fired when Jwt token state is changed
     */
    JWT_STATE_CHANGED = "JWT_STATE_CHANGED",
    /**
     * Fired when an error has occurred on the server for a session
     */
    SESSION_ERROR = "SESSION_ERROR",
    /**
     * Fired if and when the modules only have the current view of the participant
     * info from server, but unable to deduce the changes. This can happen on
     * reconnection after long period of disconnection with server.
     */
    PARTICIPANT_SYNC = "PARTICIPANT_SYNC",
    /**
     * Fired to share the latest conversation details with the Modules.
     */
    CONVERSATION_SYNC = "CONVERSATION_SYNC",
    /**
     * Fired by the modules when they have the latest participant list from server.
     */
    PARTICIPANT_LIST_UPDATE = "PARTICIPANT_LIST_UPDATE"
}

/**
 * @hidden
 * Creates and returns a promise along with its resolvers.
 */
export declare function createPromiseWithResolvers<T>(): PromiseWithResolvers<T>;

/** @internal */
declare type _CreateSessionResponseDTO = OpenAPITypes.components["schemas"]["SessionResponse"];

/**
 * Represents the event dispatcher that helps in storing and invoking event handlers.
 * @hidden
 */
export declare class EventDispatcher {
    private latestModuleEventHandlerId;
    private latestClientEventHandlerId;
    private moduleEventHandlers;
    private clientEventHandlers;
    constructor();
    private generateModuleHandlerId;
    private generateClientHandlerId;
    addModuleEventHandler<T extends EventPayload>(event: string, handler: EventHandler<T>): string;
    addClientEventHandler<T extends EventPayload>(event: string, handler: EventHandler<T>): string;
    removeModuleEventHandler(event: string, handlerId: string): void;
    removeClientEventHandler(event: string, handlerId: string): void;
    removeAllModuleHandlers(): void;
    removeAllClientHandlers(): void;
    invokeEventHandler(name: string, payload: any): Promise<void>;
}

/**
 * Represents the event handler. This is a function that is invoked when an event is dispatched.
 */
export declare type EventHandler<T extends EventPayload> = (payload: T) => unknown;

/**
 * Represents the base interface for the event payload.
 */
export declare interface EventPayload {
}

declare class EventProcessor {
    private logger;
    processEvents(events: Array<EventWrapper>): Promise<void>;
}

/**
 * Represents the event wrapper. Useful when one needs to dispatch events to invoke registered event handler.
 * @hidden
 */
export declare type EventWrapper = {
    type: string;
    event: any;
};

declare type external_2 = Record<string, never>;

/**
 * Represents the HTTP methods.
 * @hidden
 */
export declare enum HttpMethod {
    /**
     * The GET method requests a representation of the specified resource.
     */
    GET = "GET",
    /**
     * The POST method is used to submit an entity to the specified resource, often causing a change in state or side effects on the server.
     */
    POST = "POST",
    /**
     * The PUT method replaces all current representations of the target resource with the request payload.
     */
    PUT = "PUT",
    /**
     * The DELETE method deletes the specified resource.
     */
    DELETE = "DELETE"
}

/**
 * Represents the event when user has been inactive for more then idleTimeout.
 * This event payload will be passed as a parameter to the registered eventHandler that will be invoked by SDK
 */
export declare interface IdleTimeout extends SDKEvent {
    /**
     * The grace period in milliseconds before the SDK will be shutdown.
     */
    gracePeriod: number;
}

/**
 * Controller class to manage the inactivity timers.
 * @hidden
 */
export declare class InactivityTimerController {
    private idleTimer;
    private graceTimer;
    private onIdleTimeoutCallback;
    private onGraceTimeoutCallback;
    private logger;
    private continuousActivityCount;
    constructor(onIdleTimeout: (gracePeriod: number) => unknown, onGraceTimeout: () => unknown);
    setIdleTimeoutDuration(idleTimeout: number): void;
    setGraceTimeoutDuration(graceTimeout: number): void;
    startIdleTimer(): void;
    startGraceTimer(): void;
    get currentTimer(): AxpSessionInactivityTimers | undefined;
    reportIntermittentActivity(): void;
    beginContinuousActivity(): void;
    endContinuousActivity(): void;
    stopAllTimers(): void;
    private stopCurrentTimer;
    private onIdleTimeout;
    private onGraceTimeout;
}

/**
 * Represents the JWT token lifecycle.
 * @hidden
 */
export declare class JWT {
    private tokenExpiryWarningTimer;
    private tokenExpiryTimer;
    private logger;
    private ttl;
    private readonly tokenExpiryWarnPeriod;
    private beforeWarnPeriod;
    private jwtProvider;
    private token?;
    private eventProcessor;
    constructor(jwtProvider: JwtProvider, token: string);
    stop(): void;
    private startTimers;
    clear(): void;
    private restart;
    getToken(): string;
    isExpired(): boolean;
    get remainingTime(): number;
    private extractJwtExpiryTimestamp;
    private extractJwtTTL;
    setJwtToken(jwt: string): void;
    private setTokenExpiryWarningDuration;
    private setTokenExpiryDuration;
    private onTokenExpiryWarningTimeout;
    private onTokenExpiryTimeout;
}

/**
 * @public
 * An interface that needs to be implemented by Client application.
 * It provides definition for event handlers, which are invoked when jwt is about to expire or has expired.
 */
export declare interface JwtProvider {
    onExpire: () => unknown;
    onExpireWarning: (remainingTime: number) => unknown;
}

/**
 * State of the JWT assigned to SDK
 * @hidden
 */
declare enum JWTState {
    REINITIALIZED = "REINITIALIZED",
    EXPIRED = "EXPIRED"
}

/**
 * Represents the event when then state of the JWT assigned to SDK is changed(EXPIRED/REINITIALIZED).
 * @hidden
 */
export declare interface JwtStatusChangeEvent extends EventPayload {
    eventDate: Date;
    status: JWTState;
}

/**
 * @hidden
 */
declare type Latch = {
    release: () => void;
    isLatched: () => boolean;
};

/**
 * Represents the logger interface for the SDK.
 * @hidden
 */
export declare interface Logger {
    readonly name: string;
    getLevel(): LogLevel;
    debug: LoggerMethod;
    info: LoggerMethod;
    log: LoggerMethod;
    warn: LoggerMethod;
    error: LoggerMethod;
}

export declare type LoggerFactory = (loggerName: string) => Logger;

declare type LoggerMethod = (context: string, message: string, additionalDetails?: AdditionalLogDetails, ...args: Array<unknown>) => void;

/**
 * Represents the log levels supported by SDK.
 */
export declare enum LogLevel {
    ERROR = "ERROR",
    WARN = "WARN",
    INFO = "INFO",
    DEBUG = "DEBUG",
    OFF = "OFF"
}

/**
 * Validators for numeric values.
 * @hidden
 */
export declare const NumericValidators: {
    /**
     * Checks if the number is not more than the specified maximum value.
     * @param num - The number to validate.
     * @param max - The maximum value allowed.
     * @returns True if the number is not more than the maximum value, false otherwise.
     */
    notMoreThan(num: number, max: number): boolean;
    /**
     * Checks if the number is not less than the specified minimum value.
     * @param num - The number to validate.
     * @param min - The minimum value allowed.
     * @returns True if the number is not less than the minimum value, false otherwise.
     */
    notLessThan(num: number, min: number): boolean;
    /**
     * Checks if the number is between the specified minimum and maximum values (inclusive).
     * @param num - The number to validate.
     * @param min - The minimum value allowed.
     * @param max - The maximum value allowed.
     * @returns True if the number is between the minimum and maximum values, false otherwise.
     */
    between(num: number, min: number, max: number): boolean;
    /**
     * Validators for optional numeric values.
     */
    isOptionalAnd: {
        /**
         * Checks if the optional number is not more than the specified maximum value.
         * @param num - The optional number to validate.
         * @param max - The maximum value allowed.
         * @returns True if the optional number is not more than the maximum value, false otherwise.
         */
        notMoreThan(num: number | undefined, max: number): boolean;
        /**
         * Checks if the optional number is not less than the specified minimum value.
         * @param num - The optional number to validate.
         * @param min - The minimum value allowed.
         * @returns True if the optional number is not less than the minimum value, false otherwise.
         */
        notLessThan(num: number | undefined, min: number): boolean;
        /**
         * Checks if the optional number is between the specified minimum and maximum values (inclusive).
         * @param num - The optional number to validate.
         * @param min - The minimum value allowed.
         * @param max - The maximum value allowed.
         * @returns True if the optional number is between the minimum and maximum values, false otherwise.
         */
        between(num: number | undefined, min: number, max: number): boolean;
    };
};

declare namespace OpenAPITypes {
    export {
        WithRequired,
        paths,
        webhooks,
        components,
        $defs,
        external_2 as external,
        operations
    }
}

declare interface operations {

    /**
     * List Chat Sessions
     * @description List customers chat sessions
     */
    listChatSessions: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["Session"][];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * Create Chat Session
     * @description Creates a new customer chat session.
     */
    createChatSession: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
            };
        };
        requestBody: {
            content: {
                "application/json": components["schemas"]["Session"];
            };
        };
        responses: {
            /** @description Created */
            201: {
                content: {
                    "application/json": components["schemas"]["SessionResponse"];
                };
            };
            400: components["responses"]["BadRequestCreateSession"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * Get Chat Session
     * @description Get a customers chat session.
     */
    getChatSession: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                sessionId: components["parameters"]["sessionId"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["SessionResponse"];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * Delete Chat Session
     * @description Deletes a customer chat session.
     */
    endChatSession: {
        parameters: {
            query?: {
                /** @description The reason for ending the customers client session */
                reason?: "USER_CLOSED" | "USER_INACTIVE" | "UNKNOWN";
            };
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                sessionId: components["parameters"]["sessionId"];
            };
        };
        responses: {
            /** @description No Content */
            204: {
                content: never;
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * List Events
     * @description Lists events that have occurred within a session but were not delivered previously.
     *
     * A client needs to send an acknowledgement of the last event that it has processed by sending it's **eventId** in **lastEventId** so that the server can consider that event and all its previous events as delivered and will not send them again to the client.
     */
    getChatSessionEvents: {
        parameters: {
            query?: {
                /** @description The unique 36 character internal id of the last event that has been processed. */
                lastEventId?: string;
            };
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                sessionId: components["parameters"]["sessionId"];
            };
        };
        responses: {
            /** @description Event Message */
            200: {
                content: {
                    "application/json": components["schemas"]["Event"][];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
            503: components["responses"]["ServiceUnavailable"];
        };
    };
    /**
     * Create Engagement
     * @description Creates a new engagement.
     */
    createEngagement: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
            };
        };
        requestBody: {
            content: {
                "application/json": components["schemas"]["CreateEngagement"];
            };
        };
        responses: {
            /** @description Created */
            201: {
                content: {
                    "application/json": components["schemas"]["Engagement"];
                };
            };
            400: components["responses"]["BadRequestCreateEngagement"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
            503: components["responses"]["ServiceUnavailable"];
        };
    };
    /**
     * Disconnect Engagement
     * @description Disconnects from an Engagement.
     */
    disconnectEngagement: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                engagementId: components["parameters"]["engagementId"];
            };
        };
        requestBody?: {
            content: {
                "application/json": components["schemas"]["DisconnectEngagement"];
            };
        };
        responses: {
            /** @description No Content */
            204: {
                content: never;
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * Get Engagement
     * @description Gets an Engagement.
     */
    getEngagement: {
        parameters: {
            query: {
                /** @description The unique 36 character internal id that represents the session. */
                sessionId: string;
            };
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                engagementId: components["parameters"]["engagementId"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["Engagement"];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * Join Engagement
     * @description Joins an Engagement as an active participant.
     */
    joinEngagement: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                engagementId: components["parameters"]["engagementId"];
            };
        };
        requestBody?: {
            content: {
                "application/json": components["schemas"]["JoinEngagement"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["Engagement"];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
            503: components["responses"]["ServiceUnavailable"];
        };
    };
    /**
     * List Messages
     * @description List messages that have been exchanged in a chat dialog of an Engagement.
     *
     * By default, this will return messages in descending order.
     */
    listMessages: {
        parameters: {
            query: {
                /** @description The unique 36 character internal id that represents the session. */
                sessionId: string;
                dialogId: components["parameters"]["dialogId"];
                pageSize?: components["parameters"]["pageSize"];
                pageNumber?: components["parameters"]["pageNumber"];
                /**
                 * @description Ordering is performed on the "receivedAt" field, the default order is descending.
                 *
                 * To specify ascending order, "asc" should be used.
                 */
                orderBy?: string;
            };
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                engagementId: components["parameters"]["engagementId"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["MessagesPage"];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * Send Message
     * @description Sends a message into a chat dialog of an Engagement.
     */
    sendMessage: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                engagementId: components["parameters"]["engagementId"];
            };
        };
        requestBody: {
            content: {
                "application/json": components["schemas"]["SendMessage"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["MessageSent"];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
            503: components["responses"]["ServiceUnavailable"];
        };
    };
    /**
     * Generate Upload URI
     * @description Get a presigned URL to upload attachment.
     */
    generateUploadUrl: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                engagementId: components["parameters"]["engagementId"];
            };
        };
        requestBody: {
            content: {
                "application/json": components["schemas"]["GenerateUploadUrl"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["UploadUrl"];
                };
            };
            400: components["responses"]["BadRequestGenerateUploadURL"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * List Conversation Messages
     * @description List messages that have been exchanged in a conversation (that might have involved multiple messaging dialogs).
     *
     * By default, this will return messages in descending order.
     */
    listConversationMessages: {
        parameters: {
            query: {
                /** @description The unique 36 character internal id that represents the session. */
                sessionId: string;
                pageSize?: components["parameters"]["pageSize"];
                pageNumber?: components["parameters"]["pageNumber"];
                /**
                 * @description Ordering is performed on the "receivedAt" field, the default order is descending.
                 *
                 * To specify ascending order, "asc" should be used.
                 */
                orderBy?: string;
            };
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                conversationId: components["parameters"]["conversationId"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["MessagesPage"];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
        };
    };
    /**
     * Create endpoint
     * @description Register the device as an endpoint for WebRTC capabilities
     */
    createEndpoint: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
            };
        };
        requestBody: {
            content: {
                "application/json": components["schemas"]["Endpoint"];
            };
        };
        responses: {
            /** @description OK */
            200: {
                content: {
                    "application/json": components["schemas"]["EndpointResponse"];
                };
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
            503: components["responses"]["ServiceUnavailable"];
        };
    };
    /**
     * Delete endpoint
     * @description Delete endpoint registration
     */
    deleteEndpoint: {
        parameters: {
            path: {
                integrationType: components["parameters"]["integrationType"];
                integrationId: components["parameters"]["integrationId"];
                endpointId: components["parameters"]["endpointId"];
            };
        };
        responses: {
            /** @description No Content */
            204: {
                content: never;
            };
            400: components["responses"]["BadRequest"];
            401: components["responses"]["Unauthorized"];
            403: components["responses"]["Forbidden"];
            404: components["responses"]["NotFound"];
            500: components["responses"]["InternalServerError"];
            503: components["responses"]["ServiceUnavailable"];
        };
    };
}

/**
 * Iterator for type T which gives page in each iteration.
 */
export declare interface PageIterator<T> {
    /**
     * Get the items in current page.
     *
     * @returns List of items of type T in current page.
     */
    items: Readonly<Array<T>>;
    /**
     * Get the items in next page.
     *
     * @returns List of items of type T in next page and set that as current page.
     */
    next(): Promise<Readonly<Array<T>>>;
    /**
     * Get the items in previous page.
     *
     * @returns List of items of type T in previous page and set that as current page.
     */
    previous(): Promise<Readonly<Array<T>>>;
    /**
     * Get the page size.
     * @defaultValue `10`
     */
    getPageSize(): number;
    hasNext(): boolean;
    hasPrevious(): boolean;
}

/**
 * Defines the type of the participant
 */
export declare type Participant = {
    /**
     * Id of the participant.
     */
    participantId: string;
    /**
     * Type of the participant.
     */
    participantType: ParticipantType;
    /**
     * Display name of the participant.
     */
    displayName?: string;
    /**
     * Channel of the participant
     */
    channel?: string;
};

/**
 * Notifies that a participant has joined the conversation
 */
export declare interface ParticipantAdded extends ParticipantEventPayload {
    /**
     * The participant who joined the conversation
     */
    participant: Participant;
}

/**
 * Notifies that a participant has left the conversation
 */
export declare interface ParticipantDisconnected extends ParticipantEventPayload {
    /**
     * The participant who left the conversation
     */
    participant: Participant;
}

/**
 * Represents an event when a participant has joined/disconnected.
 * @hidden
 */
declare interface ParticipantEventPayload extends EventPayload {
    /**
     * The unique 36 character internal id that represents the conversation.
     */
    conversationId?: string;
    /**
     * The date-time when the event was generated by the Contact Center
     */
    eventDate: Date;
    /**
     * The channel through which the event was generated
     */
    channel: string;
}

/**
 * @hidden
 * Represents the latest list of participants in the conversation.
 */
export declare interface ParticipantListUpdate extends SDKEvent {
    /**
     * The current list of participants in the conversation
     */
    participants: Participant[];
}

/**
 * Represents the current participants in the conversation after a brief period of disconnection with server.
 * @hidden
 */
export declare interface ParticipantSync extends ParticipantEventPayload {
    currentParticipants: Participant[];
}

/**
 * Represents the various participant types that are defined by SDK and backend services.
 * no other participant type will be supported by SDK.
 */
export declare enum ParticipantType {
    CUSTOMER = "CUSTOMER",
    AGENT = "AGENT",
    SUPERVISOR = "SUPERVISOR",
    SYSTEM = "SYSTEM",
    BOT = "BOT"
}

declare interface paths {
    "/{integrationType}/{integrationId}/sessions": {
        /**
         * List Chat Sessions
         * @description List customers chat sessions
         */
        get: operations["listChatSessions"];
        /**
         * Create Chat Session
         * @description Creates a new customer chat session.
         */
        post: operations["createChatSession"];
    };
    "/{integrationType}/{integrationId}/sessions/{sessionId}": {
        /**
         * Get Chat Session
         * @description Get a customers chat session.
         */
        get: operations["getChatSession"];
        /**
         * Delete Chat Session
         * @description Deletes a customer chat session.
         */
        delete: operations["endChatSession"];
    };
    "/{integrationType}/{integrationId}/sessions/{sessionId}/events": {
        /**
         * List Events
         * @description Lists events that have occurred within a session but were not delivered previously.
         *
         * A client needs to send an acknowledgement of the last event that it has processed by sending it's **eventId** in **lastEventId** so that the server can consider that event and all its previous events as delivered and will not send them again to the client.
         */
        get: operations["getChatSessionEvents"];
    };
    "/{integrationType}/{integrationId}/engagements": {
        /**
         * Create Engagement
         * @description Creates a new engagement.
         */
        post: operations["createEngagement"];
    };
    "/{integrationType}/{integrationId}/engagements/{engagementId}:disconnect": {
        /**
         * Disconnect Engagement
         * @description Disconnects from an Engagement.
         */
        post: operations["disconnectEngagement"];
    };
    "/{integrationType}/{integrationId}/engagements/{engagementId}": {
        /**
         * Get Engagement
         * @description Gets an Engagement.
         */
        get: operations["getEngagement"];
    };
    "/{integrationType}/{integrationId}/engagements/{engagementId}:join": {
        /**
         * Join Engagement
         * @description Joins an Engagement as an active participant.
         */
        post: operations["joinEngagement"];
    };
    "/{integrationType}/{integrationId}/engagements/{engagementId}/messages": {
        /**
         * List Messages
         * @description List messages that have been exchanged in a chat dialog of an Engagement.
         *
         * By default, this will return messages in descending order.
         */
        get: operations["listMessages"];
        /**
         * Send Message
         * @description Sends a message into a chat dialog of an Engagement.
         */
        post: operations["sendMessage"];
    };
    "/{integrationType}/{integrationId}/engagements/{engagementId}:generateUploadUrl": {
        /**
         * Generate Upload URI
         * @description Get a presigned URL to upload attachment.
         */
        post: operations["generateUploadUrl"];
    };
    "/{integrationType}/{integrationId}/conversations/{conversationId}/messages": {
        /**
         * List Conversation Messages
         * @description List messages that have been exchanged in a conversation (that might have involved multiple messaging dialogs).
         *
         * By default, this will return messages in descending order.
         */
        get: operations["listConversationMessages"];
    };
    "/{integrationType}/{integrationId}/endpoints": {
        /**
         * Create endpoint
         * @description Register the device as an endpoint for WebRTC capabilities
         */
        post: operations["createEndpoint"];
    };
    "/{integrationType}/{integrationId}/endpoints/{endpointId}": {
        /**
         * Delete endpoint
         * @description Delete endpoint registration
         */
        delete: operations["deleteEndpoint"];
    };
}

/**
 * Prefixes the error message with a custom string.
 *
 * @param message - The error message to be prefixed.
 * @returns The error message with the prefix added.
 *
 * @hidden
 */
export declare function prefixErrorMessage(message: string): string;

/**
 * @hidden
 */
declare type PromiseExecutor<T> = ConstructorParameters<typeof Promise<T>>[0];

/**
 * @hidden
 */
declare type PromiseRejector = Parameters<PromiseExecutor<any>>[1];

/**
 * @hidden
 */
declare type PromiseResolver<T> = Parameters<PromiseExecutor<T>>[0];

/**
 * @hidden
 * A utility type that represents a promise along with its resolvers.
 */
export declare type PromiseWithResolvers<T> = {
    promise: Promise<T>;
    resolve: PromiseResolver<T>;
    reject: PromiseRejector;
};

/**
 * Represents the Rest Controller that will be used by core and sub modules of SDK.
 * @hidden
 */
export declare class RestController {
    #private;
    constructor(config: SDKInternalConfig, jwt: JWT);
    send(restControllerRequestOptions: RestControllerRequestOptions): Promise<Response>;
    private appendQueryParams;
    private fetchWithTimeout;
}

declare type RestControllerRequestOptions = {
    sdkBasePath?: string;
    methodType: HttpMethod;
    url: string;
    requestBody?: string;
    requestParameters?: Map<string, string>;
    isUrlFull: boolean;
    maxRequestTimeout?: number;
};

/**
 * Represents the SDK event that will be send as a parameter
 * when event handler of the client/module will be invoked.
 *
 */
export declare interface SDKEvent extends EventPayload {
    /**
     * The unique 36 character internal id that represents the session.
     */
    sessionId: string;
    /**
     * The unique 36 character internal id that represents the conversation.
     */
    conversationId: string;
    /**
     * The date-time when the event was generated by SDK
     */
    eventDate: Date;
}

/**
 * Represents the internal configuration of the SDK.
 * @hidden
 */
export declare type SDKInternalConfig = {
    axpHostName: string;
    sdkBasePath: string;
    integrationId: string;
    appKey: string;
};

/**
 * Represents the event when SDK gets shutdown.
 * This event payload will be passed as a parameter
 * to the registered eventHandler that will be invoked by SDK on shutdown.
 */
export declare interface SDKShutdown extends SDKEvent {
    /**
     * The reason for ending the customers client session.
     * @default UNKNOWN
     */
    reason?: ShutdownReason;
}

/**
 * Represents a user session.
 * @hidden
 */
export declare class Session {
    private sessionId;
    private currentSessionDetails;
    private sessionParameters;
    private conversationId;
    private sessionLatch;
    private conversations;
    private participantId;
    private sessionPoller;
    private eventProcessor;
    private logger;
    private sessionPollingManager;
    /**
     * Creates a new instance of the Session class.
     * @param sessionDetails - The session details.
     * @param conversations - The conversations associated with the session.
     * @param latch - The latch used to check if session is initialized.
     */
    constructor(sessionDetails: _CreateSessionResponseDTO, conversations: Array<AxpConversationCore>, latch: Latch, eventProcessor: EventProcessor, sessionPoller: SessionPoller, sessionPollingManager: SessionPollingManager);
    private handleSessionPollResponse;
    private handleSessionError;
    cleanup(): void;
    /**
     * Gets the session ID.
     * @returns The session ID.
     */
    getSessionId(): string;
    /**
     * Gets the conversation ID.
     * @returns The conversation ID.
     */
    getConversationId(): string;
    /**
     * Releases the session latch.
     */
    release(): void;
    /**
     * Checks if the session is latched.
     * @returns True if the session is latched, false otherwise.
     */
    isLatched(): boolean;
    /**
     * Gets the conversations associated with the session.
     * @returns The conversations.
     */
    getConversations(): AxpConversationCore[];
    /**
     * Gets the participant ID.
     * @returns The participantID.
     */
    getParticipantId(): string | undefined;
    /**
     * Gets the session parameters.
     * @returns The sessionParameters.
     */
    getSessionParameters(): Record<string, string>;
}

/** @internal */
declare type _SessionDTO = OpenAPITypes.components["schemas"]["SessionResponse"];

/**
 * Represents the event when an error has occurred on the server for a session(Session Not Found)
 * @hidden
 */
export declare interface SessionError extends SDKEvent {
    errorReason?: SessionErrorReason;
}

/**
 * The reason for Session becoming erroneous
 * @hidden
 */
export declare enum SessionErrorReason {
    SESSION_NOT_FOUND = "Session not found"
}

/**
 * @internal
 * Polls the server to get latest view of session details at a regular interval.
 */
declare class SessionPoller {
    private readonly sessionId;
    private readonly frequency;
    private readonly fallbackFrequency;
    private isPollingAllowed;
    private restController;
    private config;
    private logger;
    private pollIntervalHandle?;
    private maxConsecutiveFailures;
    private fallbackMode;
    private notifyPollResponse?;
    private notifySessionError?;
    constructor(sessionId: string, restController: RestController, config: SDKInternalConfig);
    private check;
    private fetchSession;
    private getSessionWithRetry;
    private enableFallbackMode;
    private disableFallbackMode;
    private activateFallbackMode;
    private deactivateFallbackMode;
    start(): void;
    stop(): void;
    onPoll(callback: (sessionDetails: _SessionDTO) => void): void;
    onSessionError(callback: () => void): void;
    removeListeners(): void;
}

/**
 * @hidden
 * Manages module subscriptions to the session polling.
 * Controls the session polling based on the number of modules
 * interested in session polling.
 */
export declare class SessionPollingManager {
    private readonly sessionId;
    private eventDispatcher;
    private sessionPoller;
    private checkSessionLatch;
    private moduleSubscriptionCount;
    private logger;
    constructor(sessionId: string, eventDispatcher: EventDispatcher, sessionPoller: SessionPoller, checkSessionLatch: () => boolean);
    /**
     * Subscribe to the session polling.
     * @param listener The event handler to be called when session poll round is completed.
     * @returns Handler id to be used to unsubscribe.
     */
    subscribe(listener: EventHandler<ConversationSync>): string | undefined;
    /**
     * Unsubscribe from the session polling.
     * @param listenerId Id of the listener to be removed.
     */
    unsubscribe(listenerId: string): void;
}

/**
 * The reason for ending the customers client session.
 */
export declare enum ShutdownReason {
    /**
     * The SDK has decided to shutdown the customer's session due to inactivity.
     */
    USER_INACTIVE = "USER_INACTIVE",
    /**
     * The customer has taken an action like logging off or closing the application that has triggered the session shutdown
     */
    USER_CLOSED = "USER_CLOSED",
    /**
     * The SDK has decided to Shutdown due to unknown reasons.
     */
    UNKNOWN = "UNKNOWN"
}

/**
 * Will be used to maintain the states of the object.
 * for Example, it is being used by messaging module
 * to maintain the state of the long polling.
 *
 * @hidden
 */
export declare interface StateMachine<T> {
    getState: () => T;
}

/**
 * Validators for string values.
 * @hidden
 */
export declare const StringValidators: {
    /**
     * Checks if the string is not blank (contains non-whitespace characters).
     * @param subject - The string to validate.
     * @returns True if the string is not blank, false otherwise.
     */
    notBlank(subject: string): boolean;
    /**
     * Checks if the string length is not more than the specified maximum length.
     * @param subject - The string to validate.
     * @param maxLength - The maximum length allowed.
     * @returns True if the string length is not more than the maximum length, false otherwise.
     */
    notMoreThan(subject: string, maxLength: number): boolean;
    /**
     * Checks if the string length is not less than the specified minimum length.
     * @param subject - The string to validate.
     * @param minLength - The minimum length allowed.
     * @returns True if the string length is not less than the minimum length, false otherwise.
     */
    notLessThan(subject: string, minLength: number): boolean;
    /**
     * Checks if the string is one of the allowed values.
     * @param subject - The string to validate.
     * @param allowedValues - An array of allowed values.
     * @returns True if the string is one of the allowed values, false otherwise.
     */
    isOneOf(subject: string, allowedValues: Array<string>): boolean;
    /**
     * Checks if the string length is between the specified minimum and maximum lengths (inclusive).
     * @param subject - The string to validate.
     * @param min - The minimum length allowed.
     * @param max - The maximum length allowed.
     * @returns True if the string length is between the minimum and maximum lengths, false otherwise.
     */
    isBetween(subject: string, min: number, max: number): boolean;
    /**
     * Checks if the string matches the specified regular expression.
     * @param subject - The string to validate.
     * @param exp - The regular expression pattern to match.
     * @returns True if the string matches the regular expression, false otherwise.
     */
    matches(subject: string, exp: string): boolean;
    /**
     * Checks if the string is a valid UUID.
     * @param subject - The string to validate.
     * @returns True if the string is a valid UUID, false otherwise.
     */
    isUUID(subject: string): boolean;
    /**
     * Checks if the string is a valid fully qualified domain name (FQDN).
     * @param subject - The string to validate.
     * @returns True if the string is a valid FQDN, false otherwise.
     */
    isFQDN(subject: string): boolean;
    /**
     * Validators for optional string values.
     */
    isOptionalAnd: {
        /**
         * Checks if the optional string is not undefined.
         * @param subject - The optional string to validate.
         * @returns True if the optional string is not undefined, false otherwise.
         */
        notUndefined(subject: string | undefined): boolean;
        /**
         * Checks if the optional string is not blank (contains non-whitespace characters).
         * @param subject - The optional string to validate.
         * @returns True if the optional string is not blank, false otherwise.
         */
        notBlank(subject: string | undefined): boolean;
        /**
         * Checks if the optional string length is not more than the specified maximum length.
         * @param subject - The optional string to validate.
         * @param maxLength - The maximum length allowed.
         * @returns True if the optional string length is not more than the maximum length, false otherwise.
         */
        notMoreThan(subject: string | undefined, maxLength: number): boolean;
        /**
         * Checks if the optional string length is not less than the specified minimum length.
         * @param subject - The optional string to validate.
         * @param minLength - The minimum length allowed.
         * @returns True if the optional string length is not less than the minimum length, false otherwise.
         */
        notLessThan(subject: string | undefined, minLength: number): boolean;
        /**
         * Checks if the optional string length is between the specified minimum and maximum lengths (inclusive).
         * @param subject - The optional string to validate.
         * @param min - The minimum length allowed.
         * @param max - The maximum length allowed.
         * @returns True if the optional string length is between the minimum and maximum lengths, false otherwise.
         */
        isBetween(subject: string | undefined, min: number, max: number): boolean;
        /**
         * Checks if the optional string matches the specified regular expression.
         * @param subject - The optional string to validate.
         * @param exp - The regular expression pattern to match.
         * @returns True if the optional string matches the regular expression, false otherwise.
         */
        matches(subject: string | undefined, exp: string): boolean;
        /**
         * Checks if the optional string is one of the allowed values.
         * @param subject - The optional string to validate.
         * @param allowedValues - An array of allowed values.
         * @returns True if the optional string is one of the allowed values, false otherwise.
         */
        isOneOf(subject: string | undefined, allowedValues: Array<string>): boolean;
        /**
         * Checks if the optional string is a valid UUID.
         * @param subject - The optional string to validate.
         * @returns True if the optional string is a valid UUID, false otherwise.
         */
        isUUID(subject: string | undefined): boolean;
        /**
         * Checks if the optional string is a valid FQDN.
         * @param subject - The optional string to validate.
         * @returns True if the optional string is a valid FQDN, false otherwise.
         */
        isFQDN(subject: string | undefined): boolean;
    };
};

/**
 * Represents a timer that can be started, stopped, and restarted.
 * @hidden
 */
export declare class Timer {
    /**
     * The name of the timer.
     */
    readonly name: string;
    private handle?;
    private duration;
    private onTimeoutListener;
    private startTime?;
    private logger;
    /**
     * Creates a new Timer instance.
     * @param name - The name of the timer.
     * @param duration - The duration (in milliseconds) for which the timer should run.
     * @param onTimeout - The callback to be invoked when the timer times out.
     */
    constructor(name: string, duration: number, onTimeout: () => unknown);
    /**
     * Checks if the timer is currently running.
     */
    get isRunning(): boolean;
    /**
     * Starts the timer.
     */
    start(): void;
    /**
     * Sets the duration of the timer.
     * @param interval - The new duration (in milliseconds) for the timer.
     */
    setDuration(interval: number): void;
    /**
     * Gets the current duration of the timer.
     * @returns The duration (in milliseconds) of the timer.
     */
    getDuration(): number;
    /**
     * Restarts the timer.
     */
    restart(): void;
    /**
     * Stops the timer.
     */
    stop(): void;
    private handleTimeout;
    private cleanup;
    /**
     * Gets the elapsed time since the timer was started.
     * @returns The elapsed time (in milliseconds).
     */
    get elapsedTime(): number;
    /**
     * Gets the remaining time until the timer times out.
     * @returns The remaining time (in milliseconds).
     */
    get remainingTime(): number;
}

/**
 * Converts the provided parameters into a Participant object.
 * @param participantId - The ID of the participant.
 * @param participantType - The type of the participant. Can be "CUSTOMER", "AGENT", "SUPERVISOR", "SYSTEM", or "BOT".
 * @param channel - The channel of the participant.
 * @param displayName - The display name of the participant (optional).
 * @returns The created Participant object.
 *
 * @hidden
 */
export declare function toParticipant(participantId: string, participantType: "CUSTOMER" | "AGENT" | "SUPERVISOR" | "SYSTEM" | "BOT", channel: string, displayName?: string): Participant;

/**
 * Validators for type validations.
 * @hidden
 */
export declare const TypeValidations: {
    /**
     * Checks if the value is a string.
     * @param val - The value to validate.
     * @returns True if the value is a string, false otherwise.
     */
    isString(val: any): boolean;
    /**
     * Checks if the value is a number.
     * @param val - The value to validate.
     * @returns True if the value is a number, false otherwise.
     */
    isNumber(val: any): boolean;
    /**
     * Checks if the value is a function.
     * @param val - The value to validate.
     * @returns True if the value is a function, false otherwise.
     */
    isFunction(val: any): boolean;
    /**
     * Checks if the value is an object.
     * @param val - The value to validate.
     * @returns True if the value is an object, false otherwise.
     */
    isObject(val: any): boolean;
    /**
     * Checks if the value is a non-null object.
     * @param val - The value to validate.
     * @returns True if the value is a non-null object, false otherwise.
     */
    isNonNullableObject(val: any): boolean;
    /**
     * Checks if the value is a record (an object with string keys and string values).
     * @param val - The value to validate.
     * @param maxPairs - The maximum number of key-value pairs allowed.
     * @param maxKeyLength - The maximum length of each key allowed.
     * @param maxValueLength - The maximum length of each value allowed.
     * @returns True if the value is a record, false otherwise.
     */
    isRecord(val: any, maxPairs?: number, maxKeyLength?: number, maxValueLength?: number): boolean;
    isNonNullableRecord(val: any, maxPairs?: number, maxKeyLength?: number, maxValueLength?: number): boolean;
    isOptionalAnd: {
        isString(val: any): boolean;
        isNumber(val: any): boolean;
        isFunction(val: any): boolean;
        isObject(val: any): boolean;
        isRecord(val: any, maxPairs?: number, maxKeyLength?: number, maxValueLength?: number): boolean;
    };
};

declare type webhooks = Record<string, never>;

/**
 * This file was auto-generated by openapi-typescript.
 * Do not make direct changes to the file.
 */


/** WithRequired type helpers */
declare type WithRequired<T, K extends keyof T> = T & { [P in K]-?: T[P] };

export { }
